@@ -16,7 +16,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-    define('VERSION', '0.5.1');
+    define('VERSION', '0.6');
 
     define('DB_HOST', 'localhost');
     define('DB_NAME', 'zoph');
@@ -27,9 +27,10 @@
     // Temporary addition until CSS sheet can be chosen from config page
     define('CSS_SHEET', 'css.php');
 
-    define('USE_IMAGE_SERVICE', 0);
+    define('USE_IMAGE_SERVICE', 1);
     define('IMAGE_DIR', "/data/images/");
-    define('WEB_IMAGE_DIR', "/images/"); // from webserver doc root
+    // Only needed when imaga service is off:
+    // define('WEB_IMAGE_DIR', "/images/"); // from webserver doc root
 
     // authentication method used from auth.inc.php
     // (this needs to be the name of a function in validator.inc.php)
@@ -72,10 +73,19 @@
     // the filename is relative to the image root (IMAGE_DIR)
     define('WATERMARK', 'watermark.gif');
 
+    // If set to 1, users can leave comments with photos
+    define('ALLOW_COMMENTS', 0);
+
+
     // web import of photos
     define('CLIENT_WEB_IMPORT', 1);
     define('SERVER_WEB_IMPORT', 0);
 
+    // Maximum filesize to be uploaded, in bytes:
+    // Make sure you also change "upload_max_filesize" "post_max_size"
+    // and possibly "max_execution_time" and "max_input_time" in php.ini
+    define('MAX_UPLOAD', 10000000);
+        
     // commands to use to expand uploaded archives.  set to 0 to disable.
     define('UNZIP_CMD', 0);
     //define('UNZIP_CMD', 'unzip');
@@ -148,7 +158,10 @@
     define('BACKUP_PREFIX', 'orig_');
 
     // width of the main table
-    define('DEFAULT_TABLE_WIDTH', 600);
+    // May be in pixels ("px") or percent ("%").
+    // As of v0.6, the entity is required.
+    define('DEFAULT_TABLE_WIDTH', "600px");
+    // define('DEFAULT_TABLE_WIDTH', "90%");
 
     // set to the id of a non admin user or to 0 to disable
     // note that this is a user_id, not a person_id
