@@ -61,6 +61,9 @@
           <label for="import"><?php echo translate("can import") ?></label>
           <?php echo create_pulldown("import", $this_user->get("import"), array("0" => translate("No",0), "1" => translate("Yes",0)) ) ?>
           <br>
+          <label for="leave_comments"><?php echo translate("can leave comments") ?></label>
+          <?php echo create_pulldown("leave_comments", $this_user->get("leave_comments"), array("0" => translate("No",0), "1" => translate("Yes",0)) ) ?>
+          <br>
           <label for="lightboxid"><?php echo translate("lightbox album") ?></label>
 <?php
     $lightbox_array = get_albums_select_array();
