@@ -1,22 +1,38 @@
 <?php
+/* This file is part of Zoph.
+ *
+ * Zoph is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ * 
+ * Zoph is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * You should have received a copy of the GNU General Public License
+ * along with Zoph; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
 // Very important, rtp must send header and html start tags !
+
 print $rtplang->lang_header();
-
-// these $styles are CSS for the calendar class
 ?>
-<?= $styles ? $styles : "" ?>
-<title><?= ZOPH_TITLE . ($title ? " - $title" : "") ?></title>
+<link TYPE="text/css" REL="stylesheet" HREF="<?php echo CSS_SHEET ?>">
+<?php
+    if ($extrastyle) {
+?>
+        <style type="text/css">
+            <?php echo $extrastyle ?>
+        </style>
+<?php
+    }
+?>
+<title><?php echo ZOPH_TITLE . ($title ? " - $title" : "") ?></title>
 </head>
-<body bgcolor="<?= $PAGE_BG_COLOR ?>" text="<?= $TEXT_COLOR ?>" link="<?= $LINK_COLOR ?>" vlink="<?= $VLINK_COLOR ?>">
-
-<div align="center">
-
-<table border="0" cellpadding="1" cellspacing="0" bgcolor="<?= $TABLE_BORDER_COLOR ?>"<?= $table_width ?>>
-  <tr>
-    <td bgcolor="<?= $PAGE_BG_COLOR ?>" align="right">
-      <table border="0" cellpadding="2" cellspacing="1" bgcolor="<?= $PAGE_BG_COLOR ?>">
-        <tr align="right">
-          <td bgcolor="<?= $PAGE_BG_COLOR ?>" width="100%">&nbsp;</td>
+<body>
+    <ul class="menu">
 <?php
     $tabs = array(
         translate("home", 0) => "zoph.php",
@@ -53,8 +69,14 @@ print $rtplang->lang_header();
     $tabs += array(
         translate("reports", 0) => "reports.php",
         translate("prefs", 0) => "prefs.php",
-        translate("about", 0) => "info.php",
-        translate("logout", 0) => "zoph.php?_action=logout");
+        translate("about", 0) => "info.php");
+
+    if ($user->get("user_id") == DEFAULT_USER) {
+        $tabs[translate("logon", 0)] = "zoph.php?_action=logout";
+    }
+    else {
+        $tabs[translate("logout", 0)] = "zoph.php?_action=logout";
+    }
 
     if (strpos($PHP_SELF, "/") === false) {
         $self = $PHP_SELF;
@@ -65,24 +87,15 @@ print $rtplang->lang_header();
 
     while (list($label, $page) = each($tabs)) {
         if ($page == $self) {
-            $bgcolor = $SELECTED_TAB_BG_COLOR;
-            $textcolor = $SELECTED_TAB_FONT_COLOR;
-        }
-        else {
-            $bgcolor = $TAB_BG_COLOR;
-            $textcolor = $TAB_FONT_COLOR;
-        }
-?>
-          <td bgcolor="<?= $bgcolor ?>">
-            <a href="<?= $page ?>"><font size="-1" color="<?= $textcolor ?>"> <?= $label ?></font></a>
-          </td>
-<?php
+            $class = "class=\"selected\"";
+        } else {
+	$class="";
+	}
+?><li <?php echo $class ?>><a href="<?php echo $page ?>"><?php echo $label ?></a></li><?php
     }
+    echo "\n";
 ?>
-        </tr>
-      </table>
-    </td>
-  </tr>
+    </ul>
 <?php
 require_once("breadcrumbs.inc.php");
 ?>
