@@ -47,7 +47,6 @@
 
     $title = translate("Import");
 
-    $table_width = " width=\"" . DEFAULT_TABLE_WIDTH . "\"";
 require_once("header.inc.php");
 ?>
           <h1><?php echo translate("import photos") ?></h1>
@@ -65,7 +64,7 @@ require_once("header.inc.php");
     else {
 ?>
 <tr><td>
-<input type="hidden" name="MAX_FILE_SIZE" value="10000000">
+<input type="hidden" name="MAX_FILE_SIZE" value="<?php echo MAX_UPLOAD ?>"> 
 <input type="hidden" name="_action" value="<?php echo $action ?>">
 </td></tr>
 <?php
@@ -228,6 +227,7 @@ require_once("header.inc.php");
 
     // do the import down here
     if ($_action == "import") {
+
         echo "<tr>\n<td>\n";
         // so directories are created with correct mode
         $oldumask = umask(IMPORT_UMASK);
@@ -251,22 +251,22 @@ require_once("header.inc.php");
                 $path = null;
             }
 
-            $absolute_path = "/" . cleanup_path(IMAGE_DIR . $path);
+            $absolute_path = cleanup_path(IMAGE_DIR . $path);
+            if (!running_on_windows()) {
+                $absolute_path = "/" . $absolute_path;
+            }
 
             if (file_exists($absolute_path) == false) {
-                if(mkdir($absolute_path, DIR_MODE)) {
-                    echo translate("Created directory") . ": $absolute_path<br>\n";
-                }
-                else {
-                    echo translate("Could not create directory") . ": $absolute_path<br>\n";
-                    $path = null;
-                }
+                create_dir_recursive($absolute_path) or $path = null;
             }
         }
 
         if ($name && $path) {
             $tmp_name = $HTTP_POST_FILES['_image_local']['tmp_name'];
-            $file = "/" . cleanup_path(IMAGE_DIR . "/" . $path . "/" . $name);
+            $file =  cleanup_path(IMAGE_DIR . "/" . $path . "/" . $name);
+            if (!running_on_windows()) {
+                $file = "/" . $file;
+            }
 
             if (move_uploaded_file($tmp_name, $file)) {
                 echo translate("Received file") . ": $file<br>\n";
@@ -287,13 +287,13 @@ require_once("header.inc.php");
                 }
 
                 if ($expand) {
-                    $full_path = "/" . cleanup_path(IMAGE_DIR . "/" . $path);
+                    $full_path = cleanup_path(IMAGE_DIR . "/" . $path);
+                    if (!running_on_windows()) {
+                        $full_path = "/" . $full_path;
+                    }
 
                     $tmp_path = EXTRACT_DIR . '/zoph' . time();
-                    if (!mkdir($tmp_path, DIR_MODE)) {
-                        echo translate("Could not create directory") . ": $tmp_path<br>\n";
-                        return;
-                    }
+                    create_dir($tmp_path) or die; 
 
                     $cmd = 'cd ' . escapeshellarg($tmp_path) . ' && ' .
                         $expand . ' ' . escapeshellarg($file) . ' 2>&1';
@@ -315,7 +315,26 @@ require_once("header.inc.php");
             }
             else {
                 echo translate("File upload failed") . "<br>\n";
-		echo translate("A possible cause is the upload_max_filesize variable in php.ini") . "<br>\n";
+                switch ($HTTP_POST_FILES['_image_local']["error"]) {
+                case UPLOAD_ERR_INI_SIZE:
+                    printf(translate("The uploaded file exceeds the upload_max_filesize directive (%s) in php.ini."), ini_get("upload_max_filesize"));
+                   break;
+                case UPLOAD_ERR_FORM_SIZE:
+                    printf(translate("The uploaded file exceeds the MAX_UPLOAD setting in config.inc.php (%s)."), MAX_UPLOAD);
+                    break;
+                case UPLOAD_ERR_PARTIAL:
+                    echo translate("The uploaded file was only partially uploaded.");
+                    break;
+                case UPLOAD_ERR_NO_FILE:
+                    echo translate("No file was uploaded.");
+                    break;
+                case UPLOAD_ERR_NO_TMP_DIR:
+                    translate("Missing a temporary folder.");
+                    break;
+                default:
+                    translate("An unknown file upload error occurred.");
+                }
+
             }
         }
         else if ($_image_server) {
