@@ -345,8 +345,8 @@ class photo extends zoph_table {
         }
 
         $size_string = " width=\"$width\" height=\"$height\"";
-        $alt = htmlentities($this->get("title"));
-return "<img src=\"$image_href\" class=\"" . $type . "\" " . $size_string . "alt=\"$alt\"" . ">";
+        $alt = $this->get("title");
+return "<img src=\"$image_href\" class=\"" . $type . "\" " . $size_string . " alt=\"$alt\"" . ">";
 }
 
     function get_rating($user_id) {
@@ -863,6 +863,85 @@ echo ("<br>\noutString:<br>\n" . $out_string);
             "Level" => create_text_input("level", $this->level, 4, 2));
     }
 
+    function get_comments() {
+        $sql = "select comment_id from " . DB_PREFIX . "photo_comments where" .
+            " photo_id = " .  $this->get("photo_id");
+        $comments=get_records_from_query("comment", $sql);
+        return $comments;
+    }
+
+    function get_related() {
+        $sql = "select photo_id_1 as photo_id from " . 
+            DB_PREFIX . "photo_relations where" .
+            " photo_id_2 = " .  $this->get("photo_id") .
+            " union select photo_id_2 as photo_id from " . 
+            DB_PREFIX . "photo_relations where" .
+            " photo_id_1 = " .  $this->get("photo_id");
+        $related=get_records_from_query("photo", $sql);
+        return $related;
+    }
+
+    function check_related($photo_id) {
+        $related=$this->get_related();
+        foreach($related as $rel_photo) {
+            if ($rel_photo->get("photo_id") == $photo_id) {
+                return true;
+            }
+        }
+        return false;
+    }
+    function get_relation_desc($photo_id_2) {
+        $sql = "select desc_1 from " . DB_PREFIX . "photo_relations where" .
+            " photo_id_2 = " . $this->get("photo_id") . " and " .
+            " photo_id_1 = " . escape_string($photo_id_2) . 
+            " union select desc_2 from " . DB_PREFIX . "photo_relations where" .
+            " photo_id_1 = " . $this->get("photo_id") . " and " .
+            " photo_id_2 = " . escape_string($photo_id_2) . " limit 1";
+        $result=mysql_query($sql)
+            or die("Could not get description for related photo:<br><i>$sql</i>");
+        $result=mysql_fetch_row($result);
+        return $result[0];
+    }
+    
+    function create_relation($photo_id_2, $desc_1 = null, $desc_2 = null) {
+        $sql = "insert into " . DB_PREFIX . "photo_relations values (" .
+            escape_string($this->get("photo_id")) . "," .
+            escape_string($photo_id_2) . "," .
+            "\"" . escape_string($desc_1) . "\"," .
+            "\"" . escape_string($desc_2) . "\")";
+        $result=mysql_query($sql)
+            or die_with_mysql_error("Could not create relation:<br><i>$sql</i>");
+        }
+        
+    function update_relation($photo_id_2, $desc_1 = null, $desc_2 = null) {
+        $photo_id_1=escape_string($this->get("photo_id"));
+        $photo_id_2=escape_string($photo_id_2);
+        $sql = "update " . DB_PREFIX . "photo_relations set" .
+            " desc_1=\"" . escape_string($desc_1) . "\"," .
+            " desc_2=\"" . escape_string($desc_2) . "\"" .
+            " where photo_id_1=" . $photo_id_1 .
+            " and photo_id_2=" . $photo_id_2;
+        mysql_query($sql)
+            or die_with_mysql_error("Could not update relation:<br><i>$sql</i>");
+        // A relation may be the other way around...
+        $sql = "update " . DB_PREFIX . "photo_relations set" .
+            " desc_2=\"" . escape_string($desc_1) . "\"," .
+            " desc_1=\"" . escape_string($desc_2) . "\"" .
+            " where photo_id_2=" . $photo_id_1 .
+            " and photo_id_1=" . $photo_id_2;
+        mysql_query($sql)
+            or die_with_mysql_error("Could not update relation:<br><i>$sql</i>");
+        }
+    
+    function delete_relation($photo_id_2) {
+        $ids="(" . escape_string($this->get("photo_id")) . "," .
+            escape_string($photo_id_2) . ")"; 
+        $sql = "delete from " . DB_PREFIX . "photo_relations" .
+            " where photo_id_1 in " . $ids .
+            " and photo_id_2 in " . $ids;
+        $result=mysql_query($sql)
+            or die_with_mysql_error("Could not delete relation:<br><i>$sql</i>");
+    }    
 }
 
 function get_photo_sizes_sum() {
@@ -916,7 +995,7 @@ function create_rating_graph($user) {
 	   $max_rating=$range+0.5;
            $qs =
               "search.php?rating%5B0%5D=" . $min_rating . "&_rating_op%5B0%5D=%3E%3D" .
-              "&rating%5B1%5D=" . $max_rating . "&_rating_op%5B1%5D=%3C&_action=search";
+              "&rating%5B1%5D=" . $max_rating . "&_rating_op%5B1%5D=%3C&_action=" . translate("search");
         } else {
            $qs = "photos.php?rating=null";
         }  
