@@ -29,13 +29,18 @@
     $photo = new photo($photo_id);
     */
 
+    $_qs=getvar("_qs");
+    if($user->prefs->get("auto_edit") && $_qs && $_action == "update") {
+        header("Location: photo.php?" . $_qs);
+    }
+
     $qs = preg_replace('/_crumb=\d+&?/', '', $QUERY_STRING);
     $qs = preg_replace('/_action=\w+&?/', '', $qs);
-
-    $encoded_qs = urlencode(htmlentities(getvar("_qs")));
+    $encoded_qs = urlencode(htmlentities($_qs));
     if (empty($encoded_qs)) {
         $encoded_qs = urlencode(htmlentities($qs));
     }
+
     if ($photo_id) { // would be passed for edit or delete
         $photo = new photo($photo_id);
     }
@@ -84,7 +89,7 @@
         $cells = $_cols * $_rows;
 
         $up_qs = update_query_string($request_vars, null, null, $ignore);
-	
+        
         if ($cells) {
             $_off = $cells * floor($_off / ($cells)); 
             $up_qs .= "&amp;_off=" . $_off;
@@ -92,10 +97,66 @@
         
         $up_link = "<a href=\"photos.php?$up_qs\">" . translate("Up", 0) . "</a>";
     }
+    
+    $return_qs=$_qs;
+    if(empty($return_qs)) { 
+        if ($user->prefs->get("auto_edit")) {
+            $return_qs=$qs;
+        } else {
+            $return_qs = "_action=display&amp;photo_id=" . $photo->get("photo_id");
+        }
+    }
+
+    if (!$user->is_admin()) {
+        if ($_action == "new" || $_action == "insert" ||
+            $_action == "delete" || $_action == "confirm") {
+            // only an admin can do these
+            $_action = "display"; // in case redirect fails
+            header("Location: " . add_sid("zoph.php"));
+        }
+
+        $permissions = $user->get_permissions_for_photo($photo_id);
+        if (!$permissions) {
+            $photo = new photo(-1); // in case redirect fails
+            header("Location: " . add_sid("zoph.php"));
+        }
+        else if ($permissions->get("writable") == 0) {
+            $_action = "display";
+        }
+    }
+
+
+    if (EMAIL_PHOTOS) {
+        $actionlinks["email"]="mail.php?_action=compose&amp;photo_id=" . $photo->get("photo_id");
+    }
+
+    if ($user->is_admin() || $permissions->get("writable")) {
+        $actionlinks["edit"]="photo.php?_action=edit&amp;photo_id=" . $photo->get("photo_id") . "&amp;_qs=" . $encoded_qs;
+    }
+    if ($user->get("lightbox_id")) {
+        $actionlinks["lightbox"]="photo.php?_action=lightbox&amp;" . $qs;
+    }
+    if ((ALLOW_COMMENTS) && ($user->is_admin() || $user->get("leave_comments"))) {
+        $actionlinks["add comment"]="comment.php?_action=new&amp;photo_id=" . $photo->get("photo_id");
+    }
+
+    if (!$user->prefs->get("auto_edit") && $_action=="edit" ) {
+        $actionlinks["return"]="photo.php?" .  $return_qs;
+    }
+    
+    if ($user->is_admin() && $_action!="delete") {
+        $actionlinks["select"]="photo.php?_action=select&amp;" . $qs;
+        $actionlinks["delete"]="photo.php?_action=delete&amp;photo_id=" . $photo->get("photo_id") . "&amp;_qs=" . $encoded_qs;
+    } else if ($_action=="delete") {    
+        unset($actionlinks);
+        $actionlinks["delete"]="photo.php?_action=confirm&amp;photo_id=" . $photo->get("photo_id") . "&amp;_qs=" . $encoded_qs;
+        $actionlinks["cancel"]="photo.php?" . $_qs;
+    }
 
     // jump to edit screen if auto edit pref is set
     // permission to edit checked below
     if ((!$_action || $_action == "search") && $user->prefs->get("auto_edit")) {
+        $actionlinks["return"]="photo.php?_action=display&amp;" . $return_qs;
         $_action = "edit";
     }
 
@@ -116,60 +177,69 @@
         $action = "display";
     }
 
-
-    if (!$user->is_admin()) {
-        if ($_action == "new" || $_action == "insert" ||
-            $_action == "delete" || $_action == "confirm") {
-            // only an admin can do these
-            $_action = "display"; // in case redirect fails
-            header("Location: " . add_sid("zoph.php"));
-        }
-
-        $permissions = $user->get_permissions_for_photo($photo_id);
-        if (!$permissions) {
-            $photo = new photo(-1); // in case redirect fails
-            header("Location: " . add_sid("zoph.php"));
-        }
-        else if ($permissions->get("writable") == 0) {
-            $_action = "display";
-        }
-    }
-
     if ($_action == "edit") {
+        $actionlinks["return"]="photo.php?_action=display&amp;" . $return_qs;
+        unset($actionlinks["cancel"]);
+        unset($actionlinks["edit"]);
         $action = "update";
     }
     else if ($_action == "update") {
+        unset($actionlinks["cancel"]);
+        unset($actionlinks["edit"]);
 
         $photo->set_fields($request_vars);
         $photo->update($request_vars); // pass again for add people, cats, etc
         $action = "update";
     }
     else if ($_action == "new") {
+        unset($actionlinks);
+        $actionlinks["cancel"]="photos.php?" . $_qs;
         $action = "insert";
     }
     else if ($_action == "insert") {
         $photo->set_fields($request_vars);
         $photo->insert();
         $action = "update";
+        
+        unset($actionlinks["email"]);
+        unset($actionlinks["lightbox"]);
+        unset($actionlinks["add comment"]);
+        unset($actionlinks["select"]);
+        unset($actionlinks["delete"]);
     }
     else if ($_action == "delete") {
         $action = "confirm";
     }
     else if ($_action == "confirm") {
         $photo->delete();
-        if (!$user->prefs->get("auto_edit")) {
+        //if (!$user->prefs->get("auto_edit")) {
             $user->eat_crumb();
-        }
+        //}
         $link = strip_href($user->get_last_crumb());
         if (!$link) { $link = "zoph.php"; }
         header("Location: " . add_sid($link));
-    }
+    } else if ($_action == "select") {
+        $sel_key=false;
+        if(is_array($_SESSION["selected_photo"])) {
+            $sel_key=array_search($photo_id, $_SESSION["selected_photo"]);
+        }
+        if($sel_key === false) {
+            $_SESSION["selected_photo"][]=$photo->get("photo_id");
+        }
+        $action="display";
+    } else if ($_action == "deselect") {
+        $sel_key=array_search($photo_id, $_SESSION["selected_photo"]);
+
+        if($sel_key !== false) {
+            unset($_SESSION["selected_photo"][$sel_key]);
+        }
+        header("Location: photo.php?" . html_entity_decode(urldecode($_qs)));
     // 2005-04-10 --JCT
     //
     // lightbox and rate actions moved
     // to prior to $user->is_admin() check
     //
-    else {
+    } else {
         $action = "display";
     }
 
@@ -197,58 +267,36 @@ require_once("header.inc.php");
     if ($action != "insert" && !$found) {
 ?>
           <h1>
-	  
-	  <?php echo translate("photo") ?>
-	  </h1>
+          
+          <?php echo translate("photo") ?>
+          </h1>
           <div class="main">
            <?php echo translate("No photo was found.") ?>
           </div>
 <?php
     }
     else if ($action == "display") {
+        unset($actionlinks["cancel"]);
+        unset($actionlinks["return"]);
         $title_bar = translate("photo");
         if ($num_photos) {
             $title_bar .= " " . ($offset + 1) . " of $num_photos";
         }
 ?>
           <h1>
-          <span class="actionlink">
 <?php
-        $bar = "";
-        if (EMAIL_PHOTOS) {
+    echo create_actionlinks($actionlinks);
 ?>
-            <?php echo $bar ?> <a href="mail.php?_action=compose&amp;photo_id=<?php echo $photo->get("photo_id") ?>"><?php echo translate("email") ?></a>
-<?php
-            $bar = "|";
-        }
-
-        if ($user->is_admin() || $permissions->get("writable")) {
-?>
-            <?php echo $bar ?> <a href="photo.php?_action=edit&amp;photo_id=<?php echo $photo->get("photo_id") ?>&amp;_qs=<?php echo $encoded_qs ?>"><?php echo translate("edit") ?></a>
-<?php
-            $bar = "|";
-
-            if ($user->is_admin()) {
-?>
-            | <a href="photo.php?_action=delete&amp;photo_id=<?php echo $photo->get("photo_id") ?>&amp;_qs=<?php echo $encoded_qs ?>"><?php echo translate("delete") ?></a>
-<?php
-            }
-        }
-        if ($user->get("lightbox_id")) {
-?>
-            <?php echo $bar ?> <a href="photo.php?_action=lightbox&amp;<?php echo $encoded_qs ?>"><?php echo translate("lightbox", 0) ?></a>
-<?php
-            $bar = "|";
-        }
-?>
-        </span>
           <?php echo $title_bar ?>
           </h1>
+<?php
+    require_once("selection.inc.php");
+?>
+    <div class="main">
 
 <?php
         if (ALLOW_ROTATIONS && ($user->is_admin() || $permissions->get("writable"))) {
 ?>
-        <div class="main">
           <div id="rotate">
         <form action="<?php echo $PHP_SELF ?>" method="POST">
 <input type="hidden" name="photo_id" value="<?php echo $photo->get("photo_id") ?>">
@@ -347,17 +395,55 @@ require_once("header.inc.php");
 <?php
         if ($user->prefs->get("camera_info")) {
             echo create_field_html($photo->get_camera_display_array(), 2);
-            echo "</table>";
+            echo "</table>\n";
+        }
+
+        $related=$photo->get_related();
+
+        if ($related) {
+            $header="<h2>" . translate("related photos") . "</h2>";
+            $i=0;
+            foreach($related as $rel_photo) {
+                $rel_photo->lookup();
+                if ($user->get_permissions_for_photo($rel_photo->get("photo_id")) || $user->is_admin()) {
+                    echo $header;   // Makes sure that header is only
+                    unset($header); // displayed when there are photos
+                    echo "<div class=\"thumbnail\">";
+                    if($user->is_admin()) {
+                        echo "<span class=\"actionlink\">";
+                        echo "<a href=\"relation.php?photo_id_1=" .
+                            $photo->get("photo_id") . "&amp;" . "photo_id_2=" .
+                            $rel_photo->get("photo_id") . "\">edit</a>";
+                        echo "</span>";
+                    }
+                    echo $rel_photo->get_thumbnail_link() . "<br>";
+                    echo $photo->get_relation_desc($rel_photo->get("photo_id"));
+                    echo "</div>";
+                    $i++;
+                    if($i>=5) { echo "<br>"; $i=0; }
+               }
+          }
+          echo "<br>";
+        }
+        if (ALLOW_COMMENTS) {
+            $comments=$photo->get_comments();
+
+            if($comments) {
+                echo "<h2>" . translate("comments") . "</h2>\n";
+                foreach($comments as $comment) {
+                    echo $comment->to_html($user) . "\n";
+                }
+            echo "<br>&nbsp;\n";
+            }
         }
     }
     else if ($action == "confirm") {
 ?>
           <h1><?php echo translate("photo") ?></h1>
           <div class="main">
-            <span class="actionlink">
-              <a href="photo.php?_action=confirm&amp;photo_id=<?php echo $photo->get("photo_id") ?>"><?php echo translate("delete") ?></a> |
-              <a href="photo.php?<?php echo $encoded_qs ?>"><?php echo translate("cancel") ?></a>
-            </span>
+<?php
+    echo create_actionlinks($actionlinks);
+?>
             <?php echo sprintf(translate("Confirm deletion of '%s'"), $photo->get("name")) ?>
 
 <?php
