@@ -34,7 +34,6 @@
 
     $title = translate("Preferences");
 
-    $table_width = " width=\"" . DEFAULT_TABLE_WIDTH . "\"";
     require_once("header.inc.php");
 ?>
           <h1>
@@ -188,7 +187,7 @@
         </tr>
         <tr>
           <td colspan="2" class="center">
-<input type="submit" value="<? echo translate("update") ?>">
+<input type="submit" value="<?php echo translate("update") ?>">
           </td>
         </tr>
       </table>
