@@ -60,12 +60,12 @@ function create_field_html($fields, $cols = 2, $split = null) {
 
 function create_text_input($name, $value, $size = 20, $max = 32) {
     $id=ereg_replace("^_+", "", $name);
-    return "<input type=\"text\" name=\"$name\" id=\"$id\" value=\"" . htmlentities($value) ."\" size=\"$size\" maxlength=\"$max\">\n";
+    return "<input type=\"text\" name=\"$name\" id=\"$id\" value=\"" . $value ."\" size=\"$size\" maxlength=\"$max\">\n";
 }
 
-function create_pulldown($name, $value, $value_array) {
+function create_pulldown($name, $value, $value_array, $extraopt = null) {
     $id=ereg_replace("^_+", "", $name);
-    $html = "<select name=\"$name\" id=\"$id\">\n";
+    $html = "<select name=\"$name\" id=\"$id\" $extraopt>\n";
     while (list($val, $label) = each($value_array)) {
         if ($val == $value) { $selected = " selected"; }
         else { $selected  = ""; }
@@ -234,28 +234,31 @@ function clean_request_vars($vars) {
         // keep _action now that the pager links point back to search.php
         if ($key == "_button") { continue; }
 
-	if ( is_array($val) ) { 
-	  while (list($subkey, $subval) = each($val)) {
-	    if (empty($subval)) { continue; }
+        if ( is_array($val) ) { 
+            while (list($subkey, $subval) = each($val)) {
+                if (empty($subval)) { continue; }
 
-	    //  change var_op[key] to var#key_op
-	    if (substr($key, -3) == "_op") {
-	      $newkey = substr($key, 0, -3) . '#' . $subkey . '_op';
+                //  change var_op[key] to var#key_op
+                if (substr($key, -3) == "_op") {
+                    $newkey = substr($key, 0, -3) . '#' . $subkey . '_op';
 
-	    //  change var_conj[key] to var#key_conj
-	    } elseif (substr($key, -5) == "_conj") {
-	      $newkey = substr($key, 0, -5) . '#' . $subkey . '_conj';
+                    //  change var_conj[key] to var#key_conj
+                } elseif (substr($key, -5) == "_conj") {
+                    $newkey = substr($key, 0, -5) . '#' . $subkey . '_conj';
 
-	    //  change var[key] to var#key
-	    } else {
-	      $newkey = $key . '#' . $subkey;
-	    }
-	    
-	    $interim_vars[$newkey] = $subval;
-	  }
-	} else {
-	$interim_vars[$key] = $val;
-	}
+                    //  change var_children[key] to var#key_children
+                } elseif (substr($key, -9) == "_children") {
+                    $newkey = substr($key, 0, -9) . '#' . $subkey . '_children';
+                    //  change var[key] to var#key
+                } else {
+                    $newkey = $key . '#' . $subkey;
+                }
+        
+                $interim_vars[$newkey] = $subval;
+            }
+        } else {
+            $interim_vars[$key] = $val;
+        }
     }
 
 /*
@@ -267,37 +270,44 @@ function clean_request_vars($vars) {
 */
 
     while (list($key, $val) = each($interim_vars)) {
+        // process _var variables
+        if (substr($key, 0, 1) == "_") {
 
-      // process _var variables
-      if (substr($key, 0, 1) == "_") {
+            //process _op variables
+            if (substr($key, -3) == "_op") {
+                // replace _op with -op to be compatable with the rest of application
+                $key = substr_replace($key, '-', -3, -2);
+                // get rid of ops without fields
+                $field = substr($key, 1, -3);
+                if (empty($interim_vars[$field]) && empty($interim_vars["_$field"])) { continue; }
 
-        //process _op variables
-        if (substr($key, -3) == "_op") {
-	  // replace _op with -op to be compatable with the rest of application
-	  $key = substr_replace($key, '-', -3, -2);
-          // get rid of ops without fields
-          $field = substr($key, 1, -3);
-          if (empty($interim_vars[$field]) && empty($interim_vars["_$field"])) { continue; }
-
-        //process _conj variables
-        } elseif (substr($key, -5) == "_conj") {
-	  // replace _conj with -conj to be compatable with the rest of application
-	  $key = substr_replace($key, '-', -5, -4);
-          // get rid of ops without fields
-          $field = substr($key, 1, -5);
-          if (empty($interim_vars[$field]) && empty($interim_vars["_$field"])) { continue; }
+                //process _conj variables
+            } elseif (substr($key, -5) == "_conj") {
+                // replace _conj with -conj to be compatable 
+                // with the rest of application
+                $key = substr_replace($key, '-', -5, -4);
+                // get rid of ops without fields
+                $field = substr($key, 1, -5);
+                if (empty($interim_vars[$field]) && empty($interim_vars["_$field"])) { continue; }
+                //process _children variables
+            } elseif (substr($key, -9) == "_children") {
+                // replace _children with -children to be compatable 
+                // with the rest of application
+                $key = substr_replace($key, '-', -9, -8);
+                // get rid of ops without fields
+                $field = substr($key, 1, -9);
+                if (empty($interim_vars[$field]) && empty($interim_vars["_$field"])) { continue; }
+            } else {
+                $field = substr($key, 1);
+            }
 
+            //process "_field" type variables
+            if (substr($field, 0, 5) == "field" && (empty($interim_vars[$field]) || empty($interim_vars["_$field"]))) { continue; }
         } else {
-          $field = substr($key, 1);
-	}
 
-        //process "_field" type variables
-        if (substr($field, 0, 5) == "field" && (empty($interim_vars[$field]) || empty($interim_vars["_$field"]))) { continue; }
-      } else {
-
-        //process "field" type variables
-        if (substr($key, 0, 5) == "field" && empty($interim_vars["_$key"])) { continue; }
-      }
+            //process "field" type variables
+            if (substr($key, 0, 5) == "field" && empty($interim_vars["_$key"])) { continue; }
+        }
 
         $clean_vars[$key] = $val;
     }
@@ -559,4 +569,23 @@ function cleanup_path($path) {
    return preg_replace($search,$replace, $path);
 }
 
+function create_actionlinks($actionlinks) {
+    if(is_array($actionlinks)) {
+        $html="<span class=\"actionlink\">\n";
+        while (list($key, $val) = each($actionlinks)) {
+            $html .= $bar . "<a href=\"" . $val . "\">" . translate($key, 0) . "</a>";
+            $bar=" | ";
+        }
+        $html.="</span>\n";
+        return $html;
+    }
+}
+
+function running_on_windows() {
+    if (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') {
+        return true;
+    } else {
+        return false;
+    }
+}
 ?>
