@@ -49,6 +49,7 @@ CREATE TABLE zoph_albums (
   parent_album_id int(11) NOT NULL default '0',
   album varchar(32) NOT NULL default '',
   album_description varchar(255) default NULL,
+  sortorder varchar(32) default NULL,
   PRIMARY KEY  (album_id),
   KEY album_parent_id (parent_album_id)
 ) TYPE=MyISAM;
@@ -58,7 +59,7 @@ CREATE TABLE zoph_albums (
 --
 
 
-INSERT INTO zoph_albums VALUES (1,0,'Album Root',NULL);
+INSERT INTO zoph_albums VALUES (1,0,'Album Root',NULL, NULL);
 
 --
 -- Table structure for table 'zoph_categories'
@@ -69,6 +70,7 @@ CREATE TABLE zoph_categories (
   parent_category_id int(11) NOT NULL default '0',
   category varchar(32) NOT NULL default '',
   category_description varchar(255) default NULL,
+  sortorder varchar(32) default NULL,
   PRIMARY KEY  (category_id),
   KEY cat_parent_id (parent_category_id)
 ) TYPE=MyISAM;
@@ -78,7 +80,7 @@ CREATE TABLE zoph_categories (
 --
 
 
-INSERT INTO zoph_categories VALUES (1,0,'Category Root',NULL);
+INSERT INTO zoph_categories VALUES (1,0,'Category Root',NULL,NULL);
 
 --
 -- Table structure for table 'zoph_color_schemes'
@@ -116,6 +118,21 @@ INSERT INTO zoph_color_schemes VALUES (5,'forest','336633','000000','000000','00
 INSERT INTO zoph_color_schemes VALUES (6,'black','000000','FFFFFF','FFFFFF','FFFFFF','000000','FFFFFF','000000','666666','666666','FFFFFF','999999','FFFFFF','FFFFFF');
 INSERT INTO zoph_color_schemes VALUES (7,'beach','646D7E','000000','000000','000000','F9EEE2','000000','9AADC7','C6DEFF','617C58','D0D0D0','8BB381','000000','646D7E');
 
+--
+-- Table structure for table 'zoph_comments'
+--
+
+CREATE TABLE zoph_comments (
+  comment_id int(11) NOT NULL auto_increment,
+  user_id int(11) NOT NULL default '0',
+  comment_date datetime default NULL,
+  subject varchar(255) default NULL,
+  comment blob,
+  timestamp timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
+  ipaddr varchar(16) default '',
+  PRIMARY KEY  (comment_id)
+) TYPE=MyISAM;
+
 --
 -- Table structure for table 'zoph_people'
 --
@@ -178,6 +195,16 @@ CREATE TABLE zoph_photo_categories (
 -- Dumping data for table 'zoph_photo_categories'
 --
 
+--
+-- Table structure for table 'zoph_photo_comments'
+--
+
+CREATE TABLE zoph_photo_comments (
+  photo_id int(11) NOT NULL default '0',
+  comment_id int(11) NOT NULL default '0',
+  PRIMARY KEY  (photo_id,comment_id)
+) TYPE=MyISAM;
+
 
 
 --
@@ -195,7 +222,21 @@ CREATE TABLE zoph_photo_people (
 -- Dumping data for table 'zoph_photo_people'
 --
 
+--
+-- Table structure for table 'zoph_photo_relations'
+--
 
+CREATE TABLE zoph_photo_relations (
+  photo_id_1 int(11) NOT NULL default '0',
+  photo_id_2 int(11) NOT NULL default '0',
+  desc_1 varchar(128) default NULL,
+  desc_2 varchar(128) default NULL,
+  PRIMARY KEY  (photo_id_1,photo_id_2)
+) TYPE=MyISAM;
+
+--
+-- Dumping data for table 'zoph_photo_relations'
+--
 
 --
 -- Table structure for table 'zoph_photos'
@@ -212,7 +253,7 @@ CREATE TABLE zoph_photos (
   photographer_id int(11) default NULL,
   location_id int(11) default NULL,
   view varchar(64) default NULL,
-  rating float(3,2) unsigned default NULL,
+  rating float(4,2) unsigned default NULL,
   description blob,
   date varchar(10) default NULL,
   time varchar(8) default NULL,
@@ -258,13 +299,15 @@ CREATE TABLE zoph_places (
   state varchar(32) default NULL,
   zip varchar(10) default NULL,
   country varchar(32) default NULL,
+  url varchar(1024) DEFAULT NULL,
+  urldesc varchar(32) DEFAULT NULL,
   notes varchar(255) default NULL,
   PRIMARY KEY  (place_id),
   KEY place_city (city(10)),
   KEY place_title (title(10))
 ) TYPE=MyISAM;
 
-INSERT INTO zoph_places VALUES (0,0,0,"World",NULL,NULL,NULL,NULL,NULL,NULL,NULL);
+INSERT INTO zoph_places VALUES (0,0,0,"World",NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL);
 
 --
 -- Dumping data for table 'zoph_places'
@@ -336,6 +379,7 @@ CREATE TABLE zoph_users (
   detailed_people char(1) NOT NULL default '0',
   detailed_places char(1) NOT NULL default '0',
   import char(1) NOT NULL default '0',
+  leave_comments char(1) NOT NULL default '0',
   lightbox_id int(11) default NULL,
   lastnotify datetime default NULL,
   lastlogin datetime default NULL,
@@ -348,5 +392,5 @@ CREATE TABLE zoph_users (
 --
 
 
-INSERT INTO zoph_users VALUES (1,1,'0','admin',password('admin'),'1','1','1','1','1',NULL,NULL,NULL,NULL);
+INSERT INTO zoph_users VALUES (1,1,'0','admin',password('admin'),'1','1','1','1','1','1',NULL,NULL,NULL,NULL);
 
